summaryrefslogtreecommitdiffstats
path: root/resources
diff options
context:
space:
mode:
authorFrancis Rowe <info@gluglug.org.uk>2014-12-22 06:58:23 (EST)
committer Francis Rowe <info@gluglug.org.uk>2014-12-22 06:58:23 (EST)
commit8729b1c8e35f85b7775b99ae435fb4b85c873d9b (patch)
tree24b349a0e655997d7a8b7eafbcd82b4e61e4b3ab /resources
parent19ab741a4e0f02e724be26bb24f56ec0338dba58 (diff)
downloadlibreboot-8729b1c8e35f85b7775b99ae435fb4b85c873d9b.zip
libreboot-8729b1c8e35f85b7775b99ae435fb4b85c873d9b.tar.gz
libreboot-8729b1c8e35f85b7775b99ae435fb4b85c873d9b.tar.bz2
ich9deblob: clarify that the gbe location is for factory.rom
Diffstat (limited to 'resources')
-rw-r--r--resources/utilities/ich9deblob/ich9deblob.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/resources/utilities/ich9deblob/ich9deblob.c b/resources/utilities/ich9deblob/ich9deblob.c
index 35c0188..d2f07aa 100644
--- a/resources/utilities/ich9deblob/ich9deblob.c
+++ b/resources/utilities/ich9deblob/ich9deblob.c
@@ -118,13 +118,13 @@ int main(int argc, char *argv[])
// get original GBe region location
// (it will be moved to the beginning of the flash, after the descriptor region)
unsigned int flRegionBitShift = 12;// bits 12-24 are represented.
// note for example, gbeRegionLocation is set to <<12 of actual address (in C). this is how the addresses
// are stored in the descriptor.
- unsigned int gbeRegionLocation = factoryDescriptorStruct.regionSection.flReg3.BASE << flRegionBitShift;
+ unsigned int factoryGbeRegionLocation = factoryDescriptorStruct.regionSection.flReg3.BASE << flRegionBitShift;
// Set offset so that we can read the data from
// the gbe region
- fseek(fp, gbeRegionLocation, SEEK_SET);
+ fseek(fp, factoryGbeRegionLocation, SEEK_SET);
// data will go in here
char factoryGbeBuffer[GBEREGIONSIZE];
// Read the gbe data from the factory.rom and put it in factoryGbeBuffer
@@ -152,7 +152,7 @@ int main(int argc, char *argv[])
printf("\nOriginal Descriptor start block: %08x ; Descriptor end block: %08x\n", factoryDescriptorStruct.regionSection.flReg0.BASE << flRegionBitShift, factoryDescriptorStruct.regionSection.flReg0.LIMIT << flRegionBitShift);
printf("Original BIOS start block: %08x ; BIOS end block: %08x\n", factoryDescriptorStruct.regionSection.flReg1.BASE << flRegionBitShift, factoryDescriptorStruct.regionSection.flReg1.LIMIT << flRegionBitShift);
printf("Original ME start block: %08x ; ME end block: %08x\n", factoryDescriptorStruct.regionSection.flReg2.BASE << flRegionBitShift, factoryDescriptorStruct.regionSection.flReg2.LIMIT << flRegionBitShift);
- printf("Original GBe start block: %08x ; GBe end block: %08x\n", gbeRegionLocation, factoryDescriptorStruct.regionSection.flReg3.LIMIT << flRegionBitShift);
+ printf("Original GBe start block: %08x ; GBe end block: %08x\n", factoryGbeRegionLocation, factoryDescriptorStruct.regionSection.flReg3.LIMIT << flRegionBitShift);
// Now we need to modify the descriptor so that the ME can be excluded
// from the final ROM image (libreboot one) after adding the modified
@@ -118,13 +118,13 @@ int main(int argc, char *argv[])
// (it will be moved to the beginning of the flash, after the descriptor region)
unsigned int flRegionBitShift = 12;// bits 12-24 are represented.
- // note for example, gbeRegionLocation is set to <<12 of actual address (in C). this is how the addresses
+ // note for example, factoryGbeRegionLocation is set to <<12 of actual address (in C). this is how the addresses
// are stored in the descriptor.